test/snake.c

changeset 62
5a592625e2f9
parent 60
3954c551ded3
child 63
e3cacdd636e4
--- a/test/snake.c	Fri Apr 12 22:43:00 2024 +0200
+++ b/test/snake.c	Tue Apr 16 22:06:17 2024 +0200
@@ -55,14 +55,14 @@
 }
 
 static void update_score_counter(AscSceneNode *node) {
     // tie to bottom left of the screen
     if (asc_window_active->resized) {
-        asc_vec2i bottom_left = asc_window_active->dimensions;
+        asc_vec2i bottom_right = asc_window_active->dimensions;
         asc_vec2i scale = asc_get_scale2d(node);
         asc_set_position2d(
                 node,
-                bottom_left.x - scale.width - 10,
-                bottom_left.y - scale.height - 10
+                bottom_right.x - scale.width - 10,
+                bottom_right.y - scale.height - 10
         );
     }
 }
@@ -55,14 +55,14 @@
 
 static void update_score_counter(AscSceneNode *node) {
-    // tie to bottom left of the screen
+    // tie to bottom right of the screen
     if (asc_window_active->resized) {

mercurial